@@ -2,13 +2,14 @@ import os
 import sys
 from typing import List
 from tqatest.app.core.errors import PredictException, ModelLoadException
+from tqatest.ml.model import TrainedModel_c++
 # from anscenter.app.core.config import MODEL_NAME, MODEL_PATH, MODEL_ID
 from loguru import logger
 # import ml.libs.annhub as annhub
 from tqatest.ml.libs import annhub
 
 MODEL_NAME = "TrainedModel_c++.ann"
-MODEL_PATH = "tqatest/ml/model"
+MODEL_PATH = ""
 MODEL_ID = 5122020
 
 class MachineLearningModel(object):
